@@ -11,7 +11,7 @@ def generate_matched_gaussian_bunch(num_particles, total_intensity_particles,
                                     particle_on_co=None,
                                     R_matrix=None,
                                     circumference=None,
-                                    alpha_momentum_compaction=None,
+                                    momentum_compaction_factor=None,
                                     rf_harmonic=None,
                                     rf_voltage=None,
                                     rf_phase=None,
@@ -19,6 +19,8 @@ def generate_matched_gaussian_bunch(num_particles, total_intensity_particles,
                                     tracker=None,
                                     particle_ref=None,
                                     particle_class=Particles,
+                                    co_search_settings=None,
+                                    steps_r_matrix=None,
                                     _context=None, _buffer=None, _offset=None,
                                     ):
 
@@ -38,7 +40,7 @@ def generate_matched_gaussian_bunch(num_particles, total_intensity_particles,
                           else particle_on_co),
             tracker=tracker,
             circumference=circumference,
-            alpha_momentum_compaction=alpha_momentum_compaction,
+            momentum_compaction_factor=momentum_compaction_factor,
             rf_harmonic=rf_harmonic,
             rf_voltage=rf_voltage,
             rf_phase=rf_phase,
@@ -64,5 +66,7 @@ def generate_matched_gaussian_bunch(num_particles, total_intensity_particles,
                       x_norm=x_norm, px_norm=px_norm,
                       y_norm=y_norm, py_norm=py_norm,
                       scale_with_transverse_norm_emitt=(nemitt_x, nemitt_y),
-                      weight=total_intensity_particles/num_particles)
+                      weight=total_intensity_particles/num_particles,
+                      co_search_settings=co_search_settings,
+                      steps_r_matrix=steps_r_matrix)
     return part
